==> p2-maven-plugin-1.2.0-sources.jar: org/reficio/p2/resolver/eclipse/impl/DefaultEclipseResolver.java <==
package org.reficio.p2.resolver.eclipse.impl;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class DefaultEclipseResolver
  extends java.lang.Object  implements
    org.reficio.p2.resolver.eclipse.EclipseResolver,    groovy.lang.GroovyObject {
public DefaultEclipseResolver
(java.util.List<?> repositories, java.io.File target) {}
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public final  java.io.File getTarget() { return (java.io.File)null;}
public final  java.util.List<?> getRepositories() { return (java.util.List)null;}
@java.lang.Override() public  org.reficio.p2.resolver.eclipse.EclipseResolutionResponse resolve(org.reficio.p2.resolver.eclipse.EclipseResolutionRequest request) { return (org.reficio.p2.resolver.eclipse.EclipseResolutionResponse)null;}
public  java.io.File resolveBundle(org.reficio.p2.resolver.eclipse.EclipseResolutionRequest request) { return (java.io.File)null;}
public  java.io.File resolveSource(org.reficio.p2.resolver.eclipse.EclipseResolutionRequest request) { return (java.io.File)null;}
public  java.io.File download(java.lang.String name, java.io.File destination) { return (java.io.File)null;}
}

==> p2-maven-plugin-1.7.0-sources.jar: org/reficio/p2/resolver/eclipse/impl/DefaultEclipseResolver.java <==
package org.reficio.p2.resolver.eclipse.impl;
import java.lang.*;
import java.util.*;
import java.io.*;
import java.net.*;
import groovy.lang.*;
import groovy.util.*;

@edu.umd.cs.findbugs.annotations.SuppressFBWarnings(value="SE_NO_SERIALVERSIONID") public class DefaultEclipseResolver
  extends java.lang.Object  implements
    org.reficio.p2.resolver.eclipse.EclipseResolver,    groovy.lang.GroovyObject {
;
public DefaultEclipseResolver
(java.util.List<?> repositories, java.io.File target) {}
@groovy.transform.Generated() @groovy.transform.Internal() @java.beans.Transient() public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  void setMetaClass(groovy.lang.MetaClass mc) { }
public final  java.io.File getTarget() { return (java.io.File)null;}
public final  java.util.List<?> getRepositories() { return (java.util.List<?>)null;}
@java.lang.Override() public  org.reficio.p2.resolver.eclipse.EclipseResolutionResponse resolve(org.reficio.p2.resolver.eclipse.EclipseResolutionRequest request) { return (org.reficio.p2.resolver.eclipse.EclipseResolutionResponse)null;}
public  java.io.File resolveBundle(org.reficio.p2.resolver.eclipse.EclipseResolutionRequest request) { return (java.io.File)null;}
public  java.io.File resolveSource(org.reficio.p2.resolver.eclipse.EclipseResolutionRequest request) { return (java.io.File)null;}
public  java.io.File download(java.lang.String name, java.io.File destination) { return (java.io.File)null;}
}
